#setting the directory
setwd("/Users/dataset2")

#calling the libraries
library(ape)
library(ggplot2)
library(ggtree)
library(treeio)
library(RColorBrewer)

#Reading the tree file
tree <- read.tree("/Users/dataset2/sequences.aln.fasta.treefile")

#arreading the metadata information
meta <- read.csv("/Users/dataset2/metadata.tsv",
                 header=T,sep="\t")
head(meta)

#Putting colors on the tree. 1- HP sequences. 2 - clades of variants
cor_tip_point <- brewer.pal(3,"Blues")[2]

cor <- brewer.pal(4,"Pastel2")[1:5]

p1.seqs <- meta$taxon[which(meta$lineage == "P.1")]
p1.mrca <- getMRCA(tree,p1.seqs)

p4.seqs <- meta$taxon[which(meta$lineage == "P.4")]
p4.mrca <- getMRCA(tree,p4.seqs)

b117.seqs <- meta$taxon[which(meta$lineage == "B.1.1.7")]
b117.mrca <- getMRCA(tree,b117.seqs)

b1617.seqs <- meta$taxon[which(meta$lineage == "B.1.617.2")]
b1617.mrca <- getMRCA(tree,b1617.seqs)


p <- ggtree(tr = tree, color='grey70',size=0.4)
p <- p + geom_highlight(node=p1.mrca,fill=cor[1])
p <- p + geom_highlight(node=p4.mrca,fill=cor[2])
p <- p + geom_highlight(node=b1617.mrca,fill=cor[3])
p <- p + geom_highlight(node=b117.mrca,fill=cor[4])
p

#putting samples sequenced in the tree 
pannel1 <- p %<+% meta + 
  geom_tippoint(aes(subset=(origin=="LBI")),
                fill=cor_tip_point,size=2,
                color=cor_tip_point)
pannel1