#########################################################################################
# Transmissibility analysis by measuring of Ct values
#########################################################################################

##install.packages("readxl")
##install.packages("data.table")
##install.packages("lubridate")
##install.packages("dplyr")
##install.packages("ggplot2")
##install.packages("ggpubr")
##install.packages("RColorBrewer")
##install.packages("scales")

# Load libraries
library(readxl)
library(data.table)
library(lubridate)
library(dplyr)
library(ggplot2)
library(ggpubr)
library(RColorBrewer)
library(scales)

# Set the directory
path <- "I:/Ger_Pos Analitico/Desenvolvimento e Inovacao/P&D/Colaboradores/Luige/Projetos/COVID/Capitais/Anlises/R/Cqs_doxplot_violin"
setwd(path)

# Read all files
dadosAbril21 <- read_excel("capitais_Abril_2021.xlsx")
dadosMaio21 <- read_excel("capitais_Maio_2021.xlsx")
dadosJunho21 <- read_excel("capitais_Junho_2021.xlsx")
dadosJulho21 <- read_excel("capitais_Julho_2021.xlsx")
dadosAgosto21 <- read_excel("capitais_Agosto_2021.xlsx")
dadosSetembro21 <- read_excel("capitais_Setembro_2021.xlsx")
dadosOutubro21 <- read_excel("capitais_Outubro_2021.xlsx")


# Join the data 
df <- bind_rows(dadosAbril21, dadosMaio21, dadosJunho21, dadosJulho21, dadosAgosto21,
                dadosSetembro21, dadosOutubro21)

# format the date
df$DATACOLETA <- as.Date(df$DATACOLETA)

# Keep only samples with positve results for all targets
df$MS2 <- as.numeric(df$MS2)
df <- df[-which(is.na(df$MS2)),]
df <- df[which(df$MS2 < 38),]

df$N.gene <- as.numeric(df$N.gene)
df <- df[-which(is.na(df$N.gene)),]
df <- df[which(df$N.gene < 38),]

df$ORF1ab <- as.numeric(df$ORF1ab)
df <- df[-which(is.na(df$ORF1ab)),]
df <- df[which(df$ORF1ab < 38),]

df$S.gene <- as.numeric(df$S.gene)
df <- df[-which(is.na(df$S.gene)),]
df <- df[which(df$S.gene < 38),]

#########################################################################################
# Delimit periods with predominance (90%) by capital of a given variant and compare them
# with linear regression models.
#########################################################################################

# Create vectors
capitais <- c("Belm", "Belo Horizonte", "Braslia", "Fortaleza", "Goinia", "Palmas", "Porto Alegre", "Porto Velho", "Rio de Janeiro", "So Paulo")
gama_ini <- c("2021-03-31", "2021-03-31", "2021-03-31", "2021-03-31", "2021-03-31", "2021-03-31", "2021-03-31", "2021-03-31", "2021-03-31", "2021-03-31")
gama_fim <- c("2021-06-30", "2021-07-31", "2021-06-15", "2021-07-15", "2021-07-15", "2021-06-15", "2021-07-15", "2021-06-15", "2021-06-15", "2021-07-15")
delta_ini <- c("2021-09-30", "2021-08-31", "2021-08-31", "2021-09-30", "2021-09-15", "2021-09-15", "2021-08-31", "2021-10-15", "2021-08-15", "2021-09-15")
delta_fim <- c("2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31")

# create empty dataframe and store data of capitals
n <- names(df)
df_empty <- data.frame(matrix(nrow = 1, ncol = ncol(df)))
names(df_empty) <- n
df_empty$DATACOLETA <- as.Date(df_empty$DATACOLETA)
df_empty$lineage <- NA
df.capitals <- df_empty

for(i in 1:length(capitais)){ 
  df.in <- df[which(df$NOME.DO.MUNICPIO == capitais[i] & df$DATACOLETA > gama_ini[i] & df$DATACOLETA <= gama_fim[i]),] %>%
    mutate(lineage = "aGamma")
  df.fin <- df[which(df$NOME.DO.MUNICPIO == capitais[i] & df$DATACOLETA > delta_ini[i] & df$DATACOLETA <= delta_fim[i]),] %>%
    mutate(lineage = "Delta") 
  
  y <- rbind (df.in, df.fin)
  write.csv2(y, row.names = FALSE, paste0("Ct_", capitais[i], ".csv"))
  df.capitals <- rbind(df.capitals, y)
}

# Set Gamma period
df.gamma <- df.capitals[which(df.capitals$DATACOLETA <= dmy(310721)),]

# Set Delta period
df.delta <- df.capitals[which(df.capitals$DATACOLETA >= dmy(150821)),]

# Combine datasets
df.comb <- rbind(df.gamma,df.delta)

#########################################################################################
# Plot the violin graphic and perform analysis by linear model for each target
#########################################################################################

# Set colors
cores <- RColorBrewer::brewer.pal(n = 11,name = "Spectral")
cores <- cores[c(10,2)]

# N gene
p.N <- ggplot(df.comb, aes(x = factor(lineage), y=N.gene, fill=lineage)) +
  geom_violin(trim=FALSE) + 
  geom_boxplot(width=0.25, fill="white",lwd=0.3) +
  scale_fill_manual(values=cores)+
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9),
        legend.position = "none") +
  ylim(c(0,40)) +
  xlab("Predominant lineage") + 
  ylab("Ct - N gene")
p.N

# Linear model for the target
m.N <- glm(formula = N.gene ~ lineage,data = df.comb)
summary(m.N)
conf.N <- confint(m.N, level = 0.95)

# The same pattern is repeated for each target bellow

# ORF1ab
p.ORF1ab <- ggplot(df.comb, aes(x = factor(lineage), y=ORF1ab, fill=lineage)) +
  geom_violin(trim=FALSE) + 
  geom_boxplot(width=0.25, fill="white",lwd=0.3) +
  scale_fill_manual(values=cores)+
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9),
        legend.position = "none") +
  ylim(c(0,40)) +
  xlab("Predominant lineage") + 
  ylab("Ct - ORF1ab")
p.ORF1ab

m.ORF1ab <- glm(formula = ORF1ab ~ lineage,data = df.comb)
summary(m.ORF1ab)
conf.ORF <- confint(m.ORF1ab, level = 0.95)

# S
p.S <- ggplot(df.comb, aes(x = factor(lineage), y=S.gene, fill=lineage)) +
  geom_violin(trim=FALSE) + 
  geom_boxplot(width=0.25, fill="white",lwd=0.3) +
  scale_fill_manual(values=cores)+
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9),
        legend.position = "none") +
  ylim(c(0,40)) +
  xlab("Predominant lineage") + 
  ylab("Ct - S gene")
p.S

m.S <- glm(formula = S.gene ~ lineage,data = df.comb)
summary(m.S)
conf.S <- confint(m.S, level = 0.95)

# MS2 control
p.MS2 <- ggplot(df.comb, aes(x = factor(lineage), y=MS2, fill=lineage)) +
  geom_violin(trim=FALSE) + 
  geom_boxplot(width=0.25, fill="white",lwd=0.3) +
  scale_fill_manual(values=cores)+
  theme_classic() + 
  theme(axis.text.x = element_text(size=8),
        axis.text.y = element_text(size=8),
        axis.title = element_text(size=9),
        legend.position = "none") +
  ylim(c(0,40)) +
  xlab("Predominant lineage") + 
  ylab("Ct - MS2 control")
p.MS2

m.MS2 <- glm(formula = MS2 ~ lineage,data = df.comb)
summary(m.MS2)
conf.MS2 <- confint(m.MS2, level = 0.95)

# Writes results for all models in text file 

sink("Results_models_Gamma-Delta-cutoff-90.txt")
summary(m.N)
conf.N
summary(m.ORF1ab)
conf.ORF
summary(m.S)
conf.S
summary(m.MS2)
conf.MS2
sink()

# Plot the whole stuff at once
panel <- ggarrange(p.N, p.ORF1ab, p.S, p.MS2,
                    labels = c("A","B","C","D"),
                    nrow = 2,ncol = 2,
                    vjust = 1.2,
                    hjust = -0.7,
                    font.label = list(size = 11))

# Export a pdf in rstudio to further edit
panel
