library(ggplot2)
library(data.table)
library(logr)
library(dplyr)
library(formattable)
library(writexl)

source("sintomas_gov_v2-4.R")# path of script

arquivo_analise <- "D:/Users/....../INFLUD21-08-11-2021.csv" #path of file downloaded from https://opendatasus.saude.gov.br/dataset/bd-srag-2021 on 11-11-2021
filename <- basename(arquivo_analise)
filename_ext <- sub(".csv", "", filename)

setwd("D:/Users/....") #Path destination
dir.create(paste0(getwd(),"/gov_sintomas"))
setwd(paste0(getwd(),"/gov_sintomas"))


log <- file.path(getwd(), paste0("relatrio_", filename_ext, ".log")) #cria e abre o arquivo de log
lf <- log_open(log, show_notes = FALSE)


db <- fread(arquivo_analise)

log_print(sprintf("Relatrio a partir do arquivo %s baixado no site do ministrio da sade https://https://opendatasus.saude.gov.br/dataset/bd-srag-2021", filename))

c <- count(db) #Number of lines before cleaning
log_print(sprintf("A tabela apresenta %s linhas antes da limpeza.", c))

data1 <- db[!with(db,is.na(DT_NOTIFIC) | is.na(DT_SIN_PRI) | is.na(CS_SEXO) | is.na(NU_IDADE_N) | is.na(TP_IDADE) | is.na(CS_GESTANT) | is.na(SG_UF) | is.na(CO_MUN_RES) | is.na(CO_MUN_NOT) | is.na(CO_PAIS) | is.na(VACINA_COV) |  is.na(DT_INTERNA) | is.na(CLASSI_FIN) ) ,] #campos obrigatrios

c1 <- count(data1) #Number of lines after removing lines that do not contain information in the mandatory fields, that is, incorrect data.

log_print(sprintf("A tabela apresenta %s linhas aps a retirada de linhas sem informaes(NA) nos campos obrigatrios, ou seja, dados incorretos. DT_NOTIFIC, CS_SEXO, CS_GESTANT, HISTO_VGM, CLASSI_FIN e NU_IDADE_N", c1))

rm(db)

data2 <- data1[!with(data1, is.na(FEBRE) | is.na(TOSSE) | is.na(GARGANTA) | is.na(DISPNEIA) | is.na(DESC_RESP) | is.na(SATURACAO) | is.na(DIARREIA) | is.na(VOMITO) | is.na(DOR_ABD) | is.na(FADIGA) | is.na(PERD_OLFT) | is.na(PERD_PALA) | is.na(SUPORT_VEN) | is.na(RAIOX_RES) | is.na(TOMO_RES) | is.na(HOSPITAL) | is.na(UTI) | is.na(EVOLUCAO) ), ] # campos essenciais importantes para o estudo

c2 <- count(data2) #Number of lines after removing lines without information (NA) in the fields essential to the study.

log_print(sprintf("A tabela apresenta %s linhas aps a retirada de linhas sem informaes(NA) nos campos essenciais. FEBRE, TOSSE, GARGANTA, DISPNEIA, DESC_RESP, SATURACAO, DIARREIA, VOMITO, DOR_ABD, FADIGA, PERD_OLFT, PERD_PALA, SUPORT_VEN, RAIOX_RES, TOMO_RES, HOSPITAL, UTI, EVOLUCAO", c2))

rm(data1)

data3 <- data2[!with(data2, is.na(PCR_SARS2) | is.na(PCR_RESUL) | is.na(POS_PCROUT))] # Additional essential fields for study

c3 <- count(data3) #Number of lines after removing lines without information (NA) in additional essential fields for the study

log_print(sprintf("A tabela apresenta %s linhas aps a retirada de linhas sem informaes(NA) nos campos essenciais adicionais. PCR_SARS2, PCR_RESUL e POS_PCROUT", c3))

rm(data2)

data4 <- data3 %>%
		select(DT_NOTIFIC, DT_SIN_PRI, CO_MUN_RES, CO_MUN_NOT, CS_SEXO, NU_IDADE_N, FEBRE, TOSSE, GARGANTA, DISPNEIA, DESC_RESP, SATURACAO, DIARREIA, VOMITO, DOR_ABD, FADIGA, PERD_OLFT, PERD_PALA, OUTRO_SIN, SUPORT_VEN, RAIOX_RES, TOMO_RES, HOSPITAL, DT_INTERNA, UTI, DT_ENTUTI, DT_SAIDUTI, EVOLUCAO, VACINA_COV, DOSE_1_COV, DOSE_2_COV, LAB_PR_COV, POS_PCROUT, PCR_SARS2, PCR_RESUL, CLASSI_FIN) %>%       
		filter(PCR_RESUL == 1 & POS_PCROUT == 1 & PCR_SARS2 == 1 & VACINA_COV == 2)

c4 <- count(data4) #Number of lines after removing data that are not number 1 in the fields PCR_RESUL, POS_PCROUT and PCR_SARS2 (positive result in PCR for SARS_COV_2) and that are not number 2 (not vaccinated) in the VACINA_COV field.

log_print(sprintf("A tabela apresenta %s linhas aps a retirada de dados que no possuem resultado positivo para RT_PCR de SARS_COV e que foram vacinados para SARS_COV.", c4))

#rm(data3)

data4$DT_SIN_PRI <- as.Date(data4$DT_SIN_PRI, format = "%d/%m/%Y") 
data4$DT_NOTIFIC <- as.Date(data4$DT_NOTIFIC, format = "%d/%m/%Y")
data4$DOSE_1_COV <- as.Date(data4$DOSE_1_COV, format = "%d/%m/%Y") 
data4$DOSE_2_COV <- as.Date(data4$DOSE_2_COV, format = "%d/%m/%Y") 
data4$DT_INTERNA <- as.Date(data4$DT_INTERNA, format = "%d/%m/%Y")
data4$DT_ENTUTI <- as.Date(data4$DT_ENTUTI, format = "%d/%m/%Y") 
data4$DT_SAIDUTI <- as.Date(data4$DT_SAIDUTI, format = "%d/%m/%Y")
 
data5 <- data4 %>% 
		filter(CO_MUN_RES == 150140 | CO_MUN_RES == 310620 | CO_MUN_RES == 140010 | CO_MUN_RES == 530010 | CO_MUN_RES == 500270 | CO_MUN_RES == 230440 | CO_MUN_RES == 520870 | CO_MUN_RES == 160030 | CO_MUN_RES == 130260 | CO_MUN_RES == 172100 | CO_MUN_RES == 431490 | CO_MUN_RES == 110020 | CO_MUN_RES == 330455 | CO_MUN_RES == 292740 | CO_MUN_RES == 355030) %>%
		filter(DT_NOTIFIC >= "2021-04-01" & DT_NOTIFIC <= "2021-10-31")
		

c5 <- count(data5) #Number of lines after data collection beyond the period 2021-04-01 to 10-31-2021 and cities of interest: Belm, Belo Horizonte, Boa Vista, Braslia, Campo Grande, Fortaleza, Goinia, Macap, Manaus, Palma , Porto Alegre, Porto Velho, Rio de Janeiro, Salvador and So Paulo.

log_print(sprintf("A tabela apresenta %s linhas aps a retirada de dados alm do perodo 01-04-2021 a 31-10-2021 e das cidades de interesse: Belm, Belo Horizonte, Boa Vista, Brazlia, Campo Grande, Fortaleza, Goinia, Macap, Manaus, Palma, Porto Alegre, Porto Velho, Rio de Janeiro, Salvador e So Paulo.", c5))

#rm(data4)

#Create column with month and column with age group


dataset <- data5 %>% mutate(GRUPO_IDADE = case_when(NU_IDADE_N <= 10 ~ '0-10',
 						    NU_IDADE_N >= 11 & NU_IDADE_N <= 20 ~ '11-20',
						    NU_IDADE_N >= 21 & NU_IDADE_N <= 30 ~ '21-30',
						    NU_IDADE_N >= 31 & NU_IDADE_N <= 40 ~ '31-40',
						    NU_IDADE_N >= 41 & NU_IDADE_N <= 50 ~ '41-50',
						    NU_IDADE_N >= 51 & NU_IDADE_N <= 60 ~ '51-60',
						    NU_IDADE_N >= 61 & NU_IDADE_N <= 70 ~ '61-70',
						    NU_IDADE_N >= 71 & NU_IDADE_N <= 80 ~ '71-80',
						    NU_IDADE_N >= 81 & NU_IDADE_N <= 90 ~ '81-90',
						    NU_IDADE_N >= 91 & NU_IDADE_N <= 100 ~ '91-100',
						    NU_IDADE_N >100 ~ '>100')) %>%
			   mutate(MES = months(DT_NOTIFIC)) %>%
			   mutate(SEXO = case_when(CS_SEXO == "M" ~ '1',
						    CS_SEXO == "F" ~ '2',
						    CS_SEXO != "M" & CS_SEXO != "F" ~ '9'))
		


log_print("Descrio do conjunto inicial acima definido.")

colunas <- c("CS_SEXO", "GRUPO_IDADE", "MES", "PCR_SARS2", "PCR_RESUL", "POS_PCROUT", "VACINA_COV", "FEBRE", "TOSSE", "GARGANTA", "DISPNEIA", "DESC_RESP", "SATURACAO", "DIARREIA", "VOMITO", "DOR_ABD", "FADIGA", "PERD_OLFT", "PERD_PALA", "SUPORT_VEN", "RAIOX_RES", "TOMO_RES", "HOSPITAL", "UTI", "EVOLUCAO") 

for (col in colunas){
	d <- dataset %>%
		group_by(!!as.name(col)) %>%
 			summarise(cnt = n()) %>%
 			mutate(freq = formattable::percent(cnt / sum(cnt))) %>% 
 			arrange(desc(freq))
	log_print(as.data.frame(d))
}

mes_city <- dataset %>% count(MES, CO_MUN_RES)
log_print(as.data.frame(mes_city))

dataset$FEBRE <- as.character(dataset$FEBRE)
dataset$TOSSE <- as.character(dataset$TOSSE)
dataset$GARGANTA <- as.character(dataset$GARGANTA)
dataset$DISPNEIA <- as.character(dataset$DISPNEIA)
dataset$DESC_RESP <- as.character(dataset$DESC_RESP)
dataset$SATURACAO <- as.character(dataset$SATURACAO)
dataset$DIARREIA <- as.character(dataset$DIARREIA)
dataset$VOMITO <- as.character(dataset$VOMITO)
dataset$DOR_ABD <- as.character(dataset$DOR_ABD)
dataset$FADIGA <- as.character(dataset$FADIGA)
dataset$PERD_OLFT <- as.character(dataset$PERD_OLFT)
dataset$PERD_PALA <- as.character(dataset$PERD_PALA)
dataset$SUPORT_VEN <- as.character(dataset$SUPORT_VEN)
dataset$RAIOX_RES <- as.character(dataset$RAIOX_RES)
dataset$TOMO_RES <- as.character(dataset$TOMO_RES)
dataset$UTI <- as.character(dataset$UTI)
dataset$EVOLUCAO <- as.character(dataset$EVOLUCAO)
dataset$VACINA_COV <- as.character(dataset$VACINA_COV)


###################Chosen capitals################################
#Periods defined according to the data obtained of the transition from the gamma-delta variant in each city

capitais <- c("Belem", "BeloHorizonte", "Brasilia", "Fortaleza", "Goiania", "Palmas", "PortoAlegre", "PortoVelho", "RiodeJaneiro", "SaoPaulo")
capitais_name <- c("Belm", "Belo Horizonte", "Braslia", "Fortaleza", "Goinia", "Palmas", "Porto Alegre", "Porto Velho", "Rio de Janeiro", "So Paulo")
cod_ibge <- c(150140, 310620, 530010, 230440, 520870, 172100, 431490, 110020, 330455, 355030) 
gama_ini <- c("2021-04-01", "2021-04-01", "2021-04-01", "2021-04-01", "2021-04-01", "2021-04-01", "2021-04-01", "2021-04-01", "2021-04-01", "2021-04-01") #
gama_fim <- c("2021-06-30", "2021-07-31", "2021-06-15", "2021-07-15", "2021-07-15", "2021-06-15", "2021-07-15", "2021-06-15", "2021-06-15", "2021-07-15") #
delta_ini <- c("2021-10-01", "2021-09-01", "2021-09-01", "2021-10-01", "2021-09-16", "2021-09-16", "2021-09-01", "2021-10-16", "2021-08-16", "2021-09-16") #
delta_fim <- c("2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31", "2021-10-31") #

log_print(as.data.frame(d <- data.frame(capitais = capitais, cod_ibge = cod_ibge, gama_ini = gama_ini, gama_fim = gama_fim, delta_ini = delta_ini, delta_fim = delta_fim)))
######################################################################


for(i in 1:length(capitais)){
	datain <- assign(paste0("dataset_", capitais[i], "_", gama_ini[i], "_", gama_fim[i]), dataset[which(dataset$DT_NOTIFIC >= gama_ini[i] & dataset$DT_NOTIFIC <= gama_fim[i] &  dataset$CO_MUN_RES == cod_ibge[i]), ]) %>% select(VACINA_COV, FEBRE, TOSSE, GARGANTA, DISPNEIA, DESC_RESP, SATURACAO, DIARREIA, VOMITO, DOR_ABD, FADIGA, PERD_OLFT, PERD_PALA, SUPORT_VEN, RAIOX_RES, TOMO_RES, UTI, EVOLUCAO, SEXO)
	LEGENDA <- sort(unique(unlist(datain)))
	freq <- sapply(datain, 
               function(x) table(factor(x, levels = LEGENDA, 
                                        ordered = TRUE)))
	df <- cbind(as.data.frame(LEGENDA), as.data.frame(freq))
	log_print(sprintf("Tabela de %s de %s a %s de 2021.", capitais[i], gama_ini[i], gama_fim[i]))
	log_print(df)
	write_xlsx(df, paste0("freq_dataset_", capitais[i], "_", gama_ini[i], "_", gama_fim[i], ".xlsx"))

	datafin <- assign(paste0("dataset_", capitais[i], "_", delta_ini[i], "_", delta_fim[i]), dataset[which(dataset$DT_NOTIFIC >= delta_ini[i] & dataset$DT_NOTIFIC <= delta_fim[i] &  dataset$CO_MUN_RES == cod_ibge[i]), ]) %>% select(VACINA_COV, FEBRE, TOSSE, GARGANTA, DISPNEIA, DESC_RESP, SATURACAO, DIARREIA, VOMITO, DOR_ABD, FADIGA, PERD_OLFT, PERD_PALA, SUPORT_VEN, RAIOX_RES, TOMO_RES, UTI, EVOLUCAO, SEXO)
	LEGENDA <- sort(unique(unlist(datafin)))
	freq <- sapply(datafin, 
               function(x) table(factor(x, levels = LEGENDA, 
                                        ordered = TRUE)))
	df <- cbind(as.data.frame(LEGENDA), as.data.frame(freq))
	log_print(sprintf("Tabela de %s de %s a %s de 2021.", capitais[i], delta_ini[i], delta_fim[i]))
	log_print(df)
	write_xlsx(df, paste0("freq_dataset_", capitais[i], "_", delta_ini[i], "_", delta_fim[i], ".xlsx"))
}

log_close()


#########################################FIM################################
